@@ -1,8 +1,8 @@
 # from Tools import CTool
-import Tools
+from YXKJapi import Tools
 
 
-print(Tools.CTool.getShpField(r"D:\鲍梦冬\shp\GF1_WFV1_E87.8_N33.0_20210711_L1A0005747273_ortho.shp"))
+print(CTool.getShpField(r"D:\鲍梦冬\shp\GF1_WFV1_E87.8_N33.0_20210711_L1A0005747273_ortho.shp"))
 """裁剪测试ok"""
 # print(CTool.getShpField(r"D:\鲍梦冬\shp\GF1_WFV1_E87.8_N33.0_20210711_L1A0005747273_ortho.shp"))
 # CTool.cutTif(r"D:\鲍梦冬\shp\GF1_WFV1_E87.8_N33.0_20210711_L1A0005747273_ortho.shp",
